<?php
/**
 * Business Way Single Page Options
 *
 */
$wp_customize->add_section(
    'business_way_single_page_options',
    array(
        'priority'   => 15,
        'capability' => 'edit_theme_options',
        'panel'      => 'business_way_theme_options',
        'title'      => esc_html__('Single Page Options', 'business-way'),
    )
);


/**
 * Select Featured Image
 *
 */
$wp_customize->add_setting(
    'business_way_show_feature_image_single_option',
    array(
        'default'           => $default['business_way_show_feature_image_single_option'],
        'sanitize_callback' => 'business_way_sanitize_checkbox',
    )
);
$wp_customize->add_control(
    'business_way_show_feature_image_single_option',
    array(
        'type'               => 'checkbox',
        'label'              => esc_html__('Hide Featured Image', 'business-way'),
        'description'        => esc_html__('Checked to show the featured image on all single page and single posts.', 'business-way'),
        'section'            => 'business_way_single_page_options',
        'priority'           => 20
    )
);

/**
 * Hide Author
 *
 */
$wp_customize->add_setting(
    'business_way_show_author_meta',
    array(
        'default'           => $default['business_way_show_author_meta'],
        'sanitize_callback' => 'business_way_sanitize_checkbox',
    )
);
$wp_customize->add_control(
    'business_way_show_author_meta',
    array(
        'type'               => 'checkbox',
        'label'              => esc_html__('Hide Author Meta', 'business-way'),
        'section'            => 'business_way_single_page_options',
        'priority'           => 20
    )
);

/**
 * Hide Date
 *
 */
$wp_customize->add_setting(
    'business_way_show_date_meta',
    array(
        'default'           => $default['business_way_show_date_meta'],
        'sanitize_callback' => 'business_way_sanitize_checkbox',
    )
);
$wp_customize->add_control(
    'business_way_show_date_meta',
    array(
        'type'               => 'checkbox',
        'label'              => esc_html__('Hide Date Meta', 'business-way'),
        'section'            => 'business_way_single_page_options',
        'priority'           => 20
    )
);
/**
 * Hide comments
 *
 */
$wp_customize->add_setting(
    'business_way_show_comments_meta',
    array(
        'default'           => $default['business_way_show_comments_meta'],
        'sanitize_callback' => 'business_way_sanitize_checkbox',
    )
);
$wp_customize->add_control(
    'business_way_show_comments_meta',
    array(
        'type'               => 'checkbox',
        'label'              => esc_html__('Hide Comments Meta', 'business-way'),
        'section'            => 'business_way_single_page_options',
        'priority'           => 20
    )
);

/**
 * Author Info
 *
 */
$wp_customize->add_setting(
    'business_way_author_info_show_hide_section',
    array(
        'default'           => $default['business_way_author_info_show_hide_section'],
        'sanitize_callback' => 'business_way_sanitize_checkbox',
    )
);
$wp_customize->add_control(
    'business_way_author_info_show_hide_section',
    array(
        'type'               => 'checkbox',
        'label'              => esc_html__('Author Information', 'business-way'),
        'description'        => esc_html__('It will display on the single post page. Descriptions of author can add from Users section of Dashboard.', 'business-way'),   
        'section'            => 'business_way_single_page_options',
        'priority'           => 20
    )
);

/**
 * Related Post Section
 *
 */
$wp_customize->add_setting(
    'business_way_related_post_show_hide',
    array(
        'default'           => $default['business_way_related_post_show_hide'],
        'sanitize_callback' => 'business_way_sanitize_checkbox',
    )
);
$wp_customize->add_control(
    'business_way_related_post_show_hide',
    array(
        'type'               => 'checkbox',
        'label'              => esc_html__('Show Hide Related Posts', 'business-way'),
        'section'            => 'business_way_single_page_options',
        'priority'           => 20
    )
);


/*callback functions header section*/
if ( !function_exists('business_way_related_post_callback') ) :
    function business_way_related_post_callback(){
        $related_post_hide = esc_html(business_way_get_option('business_way_related_post_show_hide'));
        if( 1 == $related_post_hide ){
            return true;
        }
        else{
            return false;
        }
    }
endif;

/**
 * Related Post Title
 *
 */
$wp_customize->add_setting(
    'business_way_related_post_title',
    array(
        'default'           => $default['business_way_related_post_title'],
        'sanitize_callback' => 'sanitize_text_field',
    )
);
$wp_customize->add_control(
    'business_way_related_post_title',
    array(
        'type'               => 'text',
        'label'              => esc_html__('Related Post Title', 'business-way'),
        'section'            => 'business_way_single_page_options',
        'priority'           => 20,
        'active_callback'    => 'business_way_related_post_callback'
    )
);
/**
 * Related Post Number
 *
 */
$wp_customize->add_setting(
    'business_way_related_post_number',
    array(
        'default'           => $default['business_way_related_post_number'],
        'sanitize_callback' => 'business_way_sanitize_number',
    )
);
$wp_customize->add_control(
    'business_way_related_post_number',
    array(
        'type'               => 'number',
        'label'              => esc_html__('Number of Related Posts', 'business-way'),
        'section'            => 'business_way_single_page_options',
        'priority'           => 20,
        'active_callback'    => 'business_way_related_post_callback',
        'input_attrs' => array(
            'min' => 1,
            'max' => 9,
            'step' => 1,
        ),
    )
);

/**
 * Related Post Image
 *
 */
$wp_customize->add_setting(
    'business_way_related_hide_featured_image',
    array(
        'default'           => $default['business_way_related_hide_featured_image'],
        'sanitize_callback' => 'business_way_sanitize_checkbox',
    )
);
$wp_customize->add_control(
    'business_way_related_hide_featured_image',
    array(
        'type'               => 'checkbox',
        'label'              => esc_html__('Show Hide Related Posts Image', 'business-way'),
        'section'            => 'business_way_single_page_options',
        'priority'           => 20,
        'active_callback'    => 'business_way_related_post_callback'
    )
);

/**
 * Related Posts title
 *
 */
$wp_customize->add_setting(
    'business_way_related_posts_title_show',
    array(
        'default'           => $default['business_way_related_posts_title_show'],
        'sanitize_callback' => 'business_way_sanitize_checkbox',
    )
);
$wp_customize->add_control(
    'business_way_related_posts_title_show',
    array(
        'type'               => 'checkbox',
        'label'              => esc_html__('Hide Show Title', 'business-way'),
        'section'            => 'business_way_single_page_options',
        'priority'           => 20,
        'active_callback'    => 'business_way_related_post_callback'
    )
);

/**
 * Related Post excerpt option
 *
 */
$wp_customize->add_setting(
    'business_way_related_posts_excerpt_show',
    array(
        'default'           => $default['business_way_related_posts_excerpt_show'],
        'sanitize_callback' => 'business_way_sanitize_checkbox',
    )
);
$wp_customize->add_control(
    'business_way_related_posts_excerpt_show',
    array(
        'type'               => 'checkbox',
        'label'              => esc_html__('Hide Show Excerpt', 'business-way'),
        'section'            => 'business_way_single_page_options',
        'priority'           => 20,
        'active_callback'    => 'business_way_related_post_callback'
    )
);

/**
 * Related Post meta options
 *
 */
$wp_customize->add_setting(
    'business_way_related_posts_meta_options',
    array(
        'default'           => $default['business_way_related_posts_meta_options'],
        'sanitize_callback' => 'business_way_sanitize_checkbox',
    )
);
$wp_customize->add_control(
    'business_way_related_posts_meta_options',
    array(
        'type'               => 'checkbox',
        'label'              => esc_html__('Meta Options For Related Post', 'business-way'),
        'section'            => 'business_way_single_page_options',
        'priority'           => 20,
        'active_callback'    => 'business_way_related_post_callback'
    )
);