<?php
/**
 * Typography Options
 *
 * @since 1.0.0
 */
$wp_customize->add_panel(
    'business_way_typography_options',
    array(
        'priority'       => 100,
        'capability'     => 'edit_theme_options',
        'theme_supports' => '',
        'title'          => esc_html__('Typography Option', 'business-way'),
    )
);

/**
 * Paragraph Font Family
 *
 * @since 1.0.0
 */
$wp_customize->add_section(
    'business_way_paragraph_typography_option',
    array(
        'title'    => esc_html__('Paragraph Font Options', 'business-way'),
        'panel'    => 'business_way_typography_options',
        'priority' => 3,
    )
);

/**
 * Paragraph Font Family 
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
    'business_way_paragraph_font_family_url',
    array(
        'default'           => $default['business_way_paragraph_font_family_url'],
        'sanitize_callback' => 'sanitize_text_field',
    )
);
$wp_customize->add_control(
    'business_way_paragraph_font_family_url',
    array(
        'type'        => 'text',
        'label'       => esc_html__('Paragraph Font Family URL ', 'business-way'),
        'description' => sprintf('%1$s <a href="%2$s" target="_blank">%3$s</a> %4$s',
        __( 'Insert', 'business-way' ),
        esc_url('https://www.google.com/fonts'),
        __('Google Font URL' , 'business-way'),
        __('for embed fonts.' ,'business-way')
        ),
        'section'  => 'business_way_paragraph_typography_option',
        'priority' => 30
    )
);

/**
 * Paragraph Font Family Name
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
    'business_way_paragraph_font_family_name',
    array(
        'default'           => $default['business_way_paragraph_font_family_name'],
        'sanitize_callback' => 'sanitize_text_field',
    )
);
$wp_customize->add_control(
    'business_way_paragraph_font_family_name',
    array(
        'type'     => 'text',
        'label'    => esc_html__('Paragraph Font Family Name ', 'business-way'),
        'description'    => esc_html__('Add Font Family Name For Paragraphs, Example: Source Sans Pro, sans-serif', 'business-way'),
        'section'  => 'business_way_paragraph_typography_option',
        'priority' => 30
    )
);

/**
 * Paragraph font size
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
    'business_way_paragraph_font_size',
    array(
        'default'           => $default['business_way_paragraph_font_size'],
        'sanitize_callback' => 'business_way_sanitize_number',
    )
);
$wp_customize->add_control(
    'business_way_paragraph_font_size',
    array(
        'type'    => 'number',
        'label'    => esc_html__('Paragraph Font Size ', 'business-way'),
        'description'    => esc_html__('Enter Font Size', 'business-way'),
        'section'  => 'business_way_paragraph_typography_option',
        'input_attrs' => array(
                        'min' => '8',
                        'max' => '16',
                        'step' => '1',
                ),
        'priority' => 30
    )
);

/**
 * Paragraph Font Weight
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
    'business_way_paragraph_font_weight',
    array(
        'default'           => $default['business_way_paragraph_font_weight'],
        'sanitize_callback' => 'business_way_sanitize_number',
    )
);
$wp_customize->add_control(
    'business_way_paragraph_font_weight',
    array(
        'type'     => 'number',
        'label'    => esc_html__('Paragraph Font Weight ', 'business-way'),
        'description'    => esc_html__('Enter Font Weight Value', 'business-way'),
        'section'  => 'business_way_paragraph_typography_option',
        'priority' => 30
    )
);

/**
 * Paragraph Line Height
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
    'business_way_paragraph_line_height',
    array(
        'default'           => $default['business_way_paragraph_line_height'],
        'sanitize_callback' => 'business_way_sanitize_floatnumber',
    )
);
$wp_customize->add_control(
    'business_way_paragraph_line_height',
    array(
        'type'    => 'number',
        'label'    => esc_html__('Paragraph Line Height ', 'business-way'),
        'description'    => esc_html__('Enter Line Height', 'business-way'),
        'section'  => 'business_way_paragraph_typography_option',
        'input_attrs' => array(
                        'min' => '0',
                        'max' => '4',
                        'step' => '0.1',
                ),
        'priority' => 30
    )
);

/**
 * Letter Spacing
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
    'business_way_paragraph_letter_spacing',
    array(
        'default'           => $default['business_way_paragraph_letter_spacing'],
        'sanitize_callback' => 'business_way_sanitize_number',
    )
);
$wp_customize->add_control(
    'business_way_paragraph_letter_spacing',
    array(
        'type'    => 'number',
        'label'    => esc_html__('Paragraph Letter Spacing', 'business-way'),
        'description'    => esc_html__('Enter Letter Spacing', 'business-way'),
        'section'  => 'business_way_paragraph_typography_option',
        'input_attrs' => array(
                        'min' => '-20',
                        'max' => '4',
                        'step' => '1',
                ),
        'priority' => 30
    )
);



/**
 * Site Title Font Family Section
 *
 * @since 1.0.0
 */
$wp_customize->add_section(
    'business_way_site_title_typography_option',
    array(
        'title'    => esc_html__('Site Title Options', 'business-way'),
        'panel'    => 'business_way_typography_options',
        'priority' => 3,
    )
);

/**
 * Site Title Font Family URL
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
    'business_way_site_title_font_family_url',
    array(
        'default'           => $default['business_way_site_title_font_family_url'],
        'sanitize_callback' => 'sanitize_text_field',
    )
);
$wp_customize->add_control(
    'business_way_site_title_font_family_url',
    array(
        'type'     => 'text',
        'label'    => esc_html__('Site Title Family URL ', 'business-way'),
        'description' => sprintf('%1$s <a href="%2$s" target="_blank">%3$s</a> %4$s',
        __( 'Insert', 'business-way' ),
        esc_url('https://www.google.com/fonts'),
        __('Google Font URL' , 'business-way'),
        __('for embed fonts.' ,'business-way')
        ),
        'section'  => 'business_way_site_title_typography_option',
        'priority' => 30
    )
);
/**
 * Site Title Family Name
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
    'business_way_site_title_font_family_name',
    array(
        'default'           => $default['business_way_site_title_font_family_name'],
        'sanitize_callback' => 'sanitize_text_field',
    )
);
$wp_customize->add_control(
    'business_way_site_title_font_family_name',
    array(
        'type'     => 'text',
        'label'    => esc_html__('Site Title Family Name ', 'business-way'),
        'description'    => esc_html__('Add Font Family Name For Site Title', 'business-way'),
        'section'  => 'business_way_site_title_typography_option',
        'priority' => 30
    )
);

/**
 * Site Title font size
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
    'business_way_site_title_font_size',
    array(
        'default'           => $default['business_way_site_title_font_size'],
        'sanitize_callback' => 'business_way_sanitize_number',
    )
);
$wp_customize->add_control(
    'business_way_site_title_font_size',
    array(
        'type'    => 'number',
        'label'    => esc_html__('Site Title Font Size ', 'business-way'),
        'description'    => esc_html__('Enter Font Size', 'business-way'),
        'section'  => 'business_way_site_title_typography_option',
        'input_attrs' => array(
                        'min' => '8',
                        'max' => '30',
                        'step' => '1',
                ),
        'priority' => 30
    )
);

/**
 * Site Title Font Weight
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
    'business_way_site_title_font_weight',
    array(
        'default'           => $default['business_way_site_title_font_weight'],
        'sanitize_callback' => 'business_way_sanitize_number',
    )
);
$wp_customize->add_control(
    'business_way_site_title_font_weight',
    array(
        'type'     => 'number',
        'label'    => esc_html__('Site Title Font Weight ', 'business-way'),
        'description'    => esc_html__('Enter Font Weight Value', 'business-way'),
        'section'  => 'business_way_site_title_typography_option',
        'priority' => 30
    )
);

/**
 * Site Title Letter Spacing
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
    'business_way_site_title_letter_spacing',
    array(
        'default'           => $default['business_way_site_title_letter_spacing'],
        'sanitize_callback' => 'business_way_sanitize_number',
    )
);
$wp_customize->add_control(
    'business_way_site_title_letter_spacing',
    array(
        'type'    => 'number',
        'label'    => esc_html__('Site Title Letter Spacing', 'business-way'),
        'description'    => esc_html__('Enter Letter Spacing', 'business-way'),
        'section'  => 'business_way_site_title_typography_option',
        'input_attrs' => array(
                        'min' => '-20',
                        'max' => '6',
                        'step' => '1',
                ),
        'priority' => 30
    )
);


/**
 * Site Tagline Font Family Section
 *
 * @since 1.0.0
 */
$wp_customize->add_section(
    'business_way_tagline_typography_option',
    array(
        'title'    => esc_html__('Site Tagline Options', 'business-way'),
        'panel'    => 'business_way_typography_options',
        'priority' => 3,
    )
);

/**
 * Site Tagline Font Family URL
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
    'business_way_tagline_font_family_url',
    array(
        'default'           => $default['business_way_tagline_font_family_url'],
        'sanitize_callback' => 'sanitize_text_field',
    )
);
$wp_customize->add_control(
    'business_way_tagline_font_family_url',
    array(
        'type'     => 'text',
        'label'    => esc_html__('Site Tagline Family URL ', 'business-way'),
        'description' => sprintf('%1$s <a href="%2$s" target="_blank">%3$s</a> %4$s',
        __( 'Insert', 'business-way' ),
        esc_url('https://www.google.com/fonts'),
        __('Google Font URL' , 'business-way'),
        __('for embed fonts.' ,'business-way')
        ),
        'section'  => 'business_way_tagline_typography_option',
        'priority' => 30
    )
);
/**
 * Site Tagline Family Name
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
    'business_way_tagline_font_family_name',
    array(
        'default'           => $default['business_way_tagline_font_family_name'],
        'sanitize_callback' => 'sanitize_text_field',
    )
);
$wp_customize->add_control(
    'business_way_tagline_font_family_name',
    array(
        'type'     => 'text',
        'label'    => esc_html__('Site Tagline Family Name ', 'business-way'),
        'description'    => esc_html__('Add Font Family Name For Site Tagline', 'business-way'),
        'section'  => 'business_way_tagline_typography_option',
        'priority' => 30
    )
);

/**
 * Site Tagline font size
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
    'business_way_tagline_font_size',
    array(
        'default'           => $default['business_way_tagline_font_size'],
        'sanitize_callback' => 'business_way_sanitize_number',
    )
);
$wp_customize->add_control(
    'business_way_tagline_font_size',
    array(
        'type'    => 'number',
        'label'    => esc_html__('Site Tagline Font Size ', 'business-way'),
        'description'    => esc_html__('Enter Font Size', 'business-way'),
        'section'  => 'business_way_tagline_typography_option',
        'input_attrs' => array(
                        'min' => '8',
                        'max' => '30',
                        'step' => '1',
                ),
        'priority' => 30
    )
);

/**
 * Site Tagline Font Weight
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
    'business_way_tagline_font_weight',
    array(
        'default'           => $default['business_way_tagline_font_weight'],
        'sanitize_callback' => 'business_way_sanitize_number',
    )
);
$wp_customize->add_control(
    'business_way_tagline_font_weight',
    array(
        'type'     => 'number',
        'label'    => esc_html__('Site Tagline Font Weight ', 'business-way'),
        'description'    => esc_html__('Enter Font Weight Value', 'business-way'),
        'section'  => 'business_way_tagline_typography_option',
        'priority' => 30
    )
);

/**
 * Site Tagline Letter Spacing
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
    'business_way_tagline_letter_spacing',
    array(
        'default'           => $default['business_way_tagline_letter_spacing'],
        'sanitize_callback' => 'business_way_sanitize_number',
    )
);
$wp_customize->add_control(
    'business_way_tagline_letter_spacing',
    array(
        'type'    => 'number',
        'label'    => esc_html__('Site Tagline Letter Spacing', 'business-way'),
        'description'    => esc_html__('Enter Letter Spacing', 'business-way'),
        'section'  => 'business_way_tagline_typography_option',
        'input_attrs' => array(
                        'min' => '-20',
                        'max' => '4',
                        'step' => '1',
                ),
        'priority' => 30
    )
);

/**
 * Heading h1 Font Family Section
 *
 * @since 1.0.0
 */
$wp_customize->add_section(
    'business_way_h1_typography_option',
    array(
        'title'    => esc_html__('Heading H1 Options', 'business-way'),
        'panel'    => 'business_way_typography_options',
        'priority' => 3,
    )
);

/**
 * Site h1 Font Family URL
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
    'business_way_h1_font_family_url',
    array(
        'default'           => $default['business_way_h1_font_family_url'],
        'sanitize_callback' => 'esc_url_raw',
    )
);
$wp_customize->add_control(
    'business_way_h1_font_family_url',
    array(
        'type'     => 'url',
        'label'    => esc_html__('Heading H1 Family URL ', 'business-way'),
        'description' => sprintf('%1$s <a href="%2$s" target="_blank">%3$s</a> %4$s',
        __( 'Insert', 'business-way' ),
        esc_url('https://www.google.com/fonts'),
        __('Google Font URL' , 'business-way'),
        __('for embed fonts.' ,'business-way')
        ),
        'section'  => 'business_way_h1_typography_option',
        'priority' => 30
    )
);
/**
 * Site h1 Family Name
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
    'business_way_h1_font_family_name',
    array(
        'default'           => $default['business_way_h1_font_family_name'],
        'sanitize_callback' => 'sanitize_text_field',
    )
);
$wp_customize->add_control(
    'business_way_h1_font_family_name',
    array(
        'type'     => 'text',
        'label'    => esc_html__('Heading H1 Family Name ', 'business-way'),
        'description'    => esc_html__('Add Font Family Name For Site H1', 'business-way'),
        'section'  => 'business_way_h1_typography_option',
        'priority' => 30
    )
);

/**
 * Site h1 font size
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
    'business_way_h1_font_size',
    array(
        'default'           => $default['business_way_h1_font_size'],
        'sanitize_callback' => 'business_way_sanitize_number',
    )
);
$wp_customize->add_control(
    'business_way_h1_font_size',
    array(
        'type'    => 'number',
        'label'    => esc_html__('Heading H1 Font Size ', 'business-way'),
        'description'    => esc_html__('Enter Font Size', 'business-way'),
        'section'  => 'business_way_h1_typography_option',
        'input_attrs' => array(
                        'min' => '20',
                        'max' => '50',
                        'step' => '1',
                ),
        'priority' => 30
    )
);

/**
 * Site h1 Font Weight
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
    'business_way_h1_font_weight',
    array(
        'default'           => $default['business_way_h1_font_weight'],
        'sanitize_callback' => 'business_way_sanitize_number',
    )
);
$wp_customize->add_control(
    'business_way_h1_font_weight',
    array(
        'type'     => 'number',
        'label'    => esc_html__('Heading H1 Font Weight ', 'business-way'),
        'description'    => esc_html__('Enter Font Weight Value', 'business-way'),
        'section'  => 'business_way_h1_typography_option',
        'priority' => 30
    )
);

/**
 * Site h1 Letter Spacing
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
    'business_way_h1_letter_spacing',
    array(
        'default'           => $default['business_way_h1_letter_spacing'],
        'sanitize_callback' => 'business_way_sanitize_number',
    )
);
$wp_customize->add_control(
    'business_way_h1_letter_spacing',
    array(
        'type'    => 'number',
        'label'    => esc_html__('Heading H1 Letter Spacing', 'business-way'),
        'description'    => esc_html__('Enter Letter Spacing', 'business-way'),
        'section'  => 'business_way_h1_typography_option',
        'input_attrs' => array(
                        'min' => '-20',
                        'max' => '4',
                        'step' => '1',
                ),
        'priority' => 30
    )
);

/**
 * Heading h2 Font Family Section
 *
 * @since 1.0.0
 */
$wp_customize->add_section(
    'business_way_h2_typography_option',
    array(
        'title'    => esc_html__('Heading H2 Options', 'business-way'),
        'panel'    => 'business_way_typography_options',
        'priority' => 3,
    )
);

/**
 * Site h2 Font Family URL
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
    'business_way_h2_font_family_url',
    array(
        'default'           => $default['business_way_h2_font_family_url'],
        'sanitize_callback' => 'esc_url_raw',
    )
);
$wp_customize->add_control(
    'business_way_h2_font_family_url',
    array(
        'type'     => 'url',
        'label'    => esc_html__('Heading H2 Family URL ', 'business-way'),
        'description' => sprintf('%1$s <a href="%2$s" target="_blank">%3$s</a> %4$s',
        __( 'Insert', 'business-way' ),
        esc_url('https://www.google.com/fonts'),
        __('Google Font URL' , 'business-way'),
        __('for embed fonts.' ,'business-way')
        ),
        'section'  => 'business_way_h2_typography_option',
        'priority' => 30
    )
);
/**
 * Site h2 Family Name
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
    'business_way_h2_font_family_name',
    array(
        'default'           => $default['business_way_h2_font_family_name'],
        'sanitize_callback' => 'sanitize_text_field',
    )
);
$wp_customize->add_control(
    'business_way_h2_font_family_name',
    array(
        'type'     => 'text',
        'label'    => esc_html__('Heading H2 Family Name ', 'business-way'),
        'description'    => esc_html__('Add Font Family Name For Site H2', 'business-way'),
        'section'  => 'business_way_h2_typography_option',
        'priority' => 30
    )
);

/**
 * Site h2 font size
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
    'business_way_h2_font_size',
    array(
        'default'           => $default['business_way_h2_font_size'],
        'sanitize_callback' => 'business_way_sanitize_number',
    )
);
$wp_customize->add_control(
    'business_way_h2_font_size',
    array(
        'type'    => 'number',
        'label'    => esc_html__('Heading H2 Font Size ', 'business-way'),
        'description'    => esc_html__('Enter Font Size', 'business-way'),
        'section'  => 'business_way_h2_typography_option',
        'input_attrs' => array(
                        'min' => '20',
                        'max' => '50',
                        'step' => '1',
                ),
        'priority' => 30
    )
);

/**
 * Site h2 Font Weight
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
    'business_way_h2_font_weight',
    array(
        'default'           => $default['business_way_h2_font_weight'],
        'sanitize_callback' => 'business_way_sanitize_number',
    )
);
$wp_customize->add_control(
    'business_way_h2_font_weight',
    array(
        'type'     => 'number',
        'label'    => esc_html__('Heading H2 Font Weight ', 'business-way'),
        'description'    => esc_html__('Enter Font Weight Value', 'business-way'),
        'section'  => 'business_way_h2_typography_option',
        'priority' => 30
    )
);

/**
 * Site h2 Letter Spacing
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
    'business_way_h2_letter_spacing',
    array(
        'default'           => $default['business_way_h2_letter_spacing'],
        'sanitize_callback' => 'business_way_sanitize_number',
    )
);
$wp_customize->add_control(
    'business_way_h2_letter_spacing',
    array(
        'type'    => 'number',
        'label'    => esc_html__('Heading H2 Letter Spacing', 'business-way'),
        'description'    => esc_html__('Enter Letter Spacing', 'business-way'),
        'section'  => 'business_way_h2_typography_option',
        'input_attrs' => array(
                        'min' => '-20',
                        'max' => '4',
                        'step' => '1',
                ),
        'priority' => 30
    )
);

/**
 * Heading h3 Font Family Section
 *
 * @since 1.0.0
 */
$wp_customize->add_section(
    'business_way_h3_typography_option',
    array(
        'title'    => esc_html__('Heading H3 Options', 'business-way'),
        'panel'    => 'business_way_typography_options',
        'priority' => 3,
    )
);

/**
 * Site h3 Font Family URL
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
    'business_way_h3_font_family_url',
    array(
        'default'           => $default['business_way_h3_font_family_url'],
        'sanitize_callback' => 'esc_url_raw',
    )
);
$wp_customize->add_control(
    'business_way_h3_font_family_url',
    array(
        'type'     => 'url',
        'label'    => esc_html__('Heading H3 Family URL ', 'business-way'),
        'description'    => esc_html__('Add Font Family URL For Site H3', 'business-way'),
        'section'  => 'business_way_h3_typography_option',
        'priority' => 30
    )
);
/**
 * Site h3 Family Name
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
    'business_way_h3_font_family_name',
    array(
        'default'           => $default['business_way_h3_font_family_name'],
        'sanitize_callback' => 'sanitize_text_field',
    )
);
$wp_customize->add_control(
    'business_way_h3_font_family_name',
    array(
        'type'     => 'text',
        'label'    => esc_html__('Heading H3 Family Name ', 'business-way'),
        'description'    => esc_html__('Add Font Family Name For Site H3', 'business-way'),
        'section'  => 'business_way_h3_typography_option',
        'priority' => 30
    )
);

/**
 * Site h3 font size
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
    'business_way_h3_font_size',
    array(
        'default'           => $default['business_way_h3_font_size'],
        'sanitize_callback' => 'business_way_sanitize_number',
    )
);
$wp_customize->add_control(
    'business_way_h3_font_size',
    array(
        'type'    => 'number',
        'label'    => esc_html__('Heading H3 Font Size ', 'business-way'),
        'description'    => esc_html__('Enter Font Size', 'business-way'),
        'section'  => 'business_way_h3_typography_option',
        'input_attrs' => array(
                        'min' => '20',
                        'max' => '50',
                        'step' => '1',
                ),
        'priority' => 30
    )
);

/**
 * Site h3 Font Weight
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
    'business_way_h3_font_weight',
    array(
        'default'           => $default['business_way_h3_font_weight'],
        'sanitize_callback' => 'business_way_sanitize_number',
    )
);
$wp_customize->add_control(
    'business_way_h3_font_weight',
    array(
        'type'     => 'number',
        'label'    => esc_html__('Heading H3 Font Weight ', 'business-way'),
        'description'    => esc_html__('Enter Font Weight Value', 'business-way'),
        'section'  => 'business_way_h3_typography_option',
        'priority' => 30
    )
);

/**
 * Site h3 Letter Spacing
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
    'business_way_h3_letter_spacing',
    array(
        'default'           => $default['business_way_h3_letter_spacing'],
        'sanitize_callback' => 'business_way_sanitize_number',
    )
);
$wp_customize->add_control(
    'business_way_h3_letter_spacing',
    array(
        'type'    => 'number',
        'label'    => esc_html__('Heading H3 Letter Spacing', 'business-way'),
        'description'    => esc_html__('Enter Letter Spacing', 'business-way'),
        'section'  => 'business_way_h3_typography_option',
        'input_attrs' => array(
                        'min' => '-20',
                        'max' => '4',
                        'step' => '1',
                ),
        'priority' => 30
    )
);

/**
 * Heading h4 Font Family Section
 *
 * @since 1.0.0
 */
$wp_customize->add_section(
    'business_way_h4_typography_option',
    array(
        'title'    => esc_html__('Heading H4 Options', 'business-way'),
        'panel'    => 'business_way_typography_options',
        'priority' => 3,
    )
);

/**
 * Site h4 Font Family URL
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
    'business_way_h4_font_family_url',
    array(
        'default'           => $default['business_way_h4_font_family_url'],
        'sanitize_callback' => 'esc_url_raw',
    )
);
$wp_customize->add_control(
    'business_way_h4_font_family_url',
    array(
        'type'     => 'url',
        'label'    => esc_html__('Heading H4 Family URL ', 'business-way'),
        'description' => sprintf('%1$s <a href="%2$s" target="_blank">%3$s</a> %4$s',
        __( 'Insert', 'business-way' ),
        esc_url('https://www.google.com/fonts'),
        __('Google Font URL' , 'business-way'),
        __('for embed fonts.' ,'business-way')
        ),
        'section'  => 'business_way_h4_typography_option',
        'priority' => 30
    )
);
/**
 * Site h4 Family Name
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
    'business_way_h4_font_family_name',
    array(
        'default'           => $default['business_way_h4_font_family_name'],
        'sanitize_callback' => 'sanitize_text_field',
    )
);
$wp_customize->add_control(
    'business_way_h4_font_family_name',
    array(
        'type'     => 'text',
        'label'    => esc_html__('Heading H4 Family Name ', 'business-way'),
        'description'    => esc_html__('Add Font Family Name For Site H4', 'business-way'),
        'section'  => 'business_way_h4_typography_option',
        'priority' => 30
    )
);

/**
 * Site h4 font size
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
    'business_way_h4_font_size',
    array(
        'default'           => $default['business_way_h4_font_size'],
        'sanitize_callback' => 'business_way_sanitize_number',
    )
);
$wp_customize->add_control(
    'business_way_h4_font_size',
    array(
        'type'    => 'number',
        'label'    => esc_html__('Heading H4 Font Size ', 'business-way'),
        'description'    => esc_html__('Enter Font Size', 'business-way'),
        'section'  => 'business_way_h4_typography_option',
        'input_attrs' => array(
                        'min' => '20',
                        'max' => '50',
                        'step' => '1',
                ),
        'priority' => 30
    )
);

/**
 * Site h4 Font Weight
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
    'business_way_h4_font_weight',
    array(
        'default'           => $default['business_way_h4_font_weight'],
        'sanitize_callback' => 'business_way_sanitize_number',
    )
);
$wp_customize->add_control(
    'business_way_h4_font_weight',
    array(
        'type'     => 'number',
        'label'    => esc_html__('Heading H4 Font Weight ', 'business-way'),
        'description'    => esc_html__('Enter Font Weight Value', 'business-way'),
        'section'  => 'business_way_h4_typography_option',
        'priority' => 30
    )
);

/**
 * Site h4 Letter Spacing
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
    'business_way_h4_letter_spacing',
    array(
        'default'           => $default['business_way_h4_letter_spacing'],
        'sanitize_callback' => 'business_way_sanitize_number',
    )
);
$wp_customize->add_control(
    'business_way_h4_letter_spacing',
    array(
        'type'    => 'number',
        'label'    => esc_html__('Heading H4 Letter Spacing', 'business-way'),
        'description'    => esc_html__('Enter Letter Spacing', 'business-way'),
        'section'  => 'business_way_h4_typography_option',
        'input_attrs' => array(
                        'min' => '-20',
                        'max' => '4',
                        'step' => '.5',
                ),
        'priority' => 30
    )
);

/**
 * Heading h5 Font Family Section
 *
 * @since 1.0.0
 */
$wp_customize->add_section(
    'business_way_h5_typography_option',
    array(
        'title'    => esc_html__('Heading H5 Options', 'business-way'),
        'panel'    => 'business_way_typography_options',
        'priority' => 3,
    )
);

/**
 * Site h5 Font Family URL
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
    'business_way_h5_font_family_url',
    array(
        'default'           => $default['business_way_h5_font_family_url'],
        'sanitize_callback' => 'esc_url_raw',
    )
);
$wp_customize->add_control(
    'business_way_h5_font_family_url',
    array(
        'type'     => 'url',
        'label'    => esc_html__('Heading H5 Family URL ', 'business-way'),
        'description' => sprintf('%1$s <a href="%2$s" target="_blank">%3$s</a> %4$s',
        __( 'Insert', 'business-way' ),
        esc_url('https://www.google.com/fonts'),
        __('Google Font URL' , 'business-way'),
        __('for embed fonts.' ,'business-way')
        ),
        'section'  => 'business_way_h5_typography_option',
        'priority' => 30
    )
);
/**
 * Site h5 Family Name
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
    'business_way_h5_font_family_name',
    array(
        'default'           => $default['business_way_h5_font_family_name'],
        'sanitize_callback' => 'sanitize_text_field',
    )
);
$wp_customize->add_control(
    'business_way_h5_font_family_name',
    array(
        'type'     => 'text',
        'label'    => esc_html__('Heading H5 Family Name ', 'business-way'),
        'description'    => esc_html__('Add Font Family Name For Site H5', 'business-way'),
        'section'  => 'business_way_h5_typography_option',
        'priority' => 30
    )
);

/**
 * Site h5 font size
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
    'business_way_h5_font_size',
    array(
        'default'           => $default['business_way_h5_font_size'],
        'sanitize_callback' => 'business_way_sanitize_number',
    )
);
$wp_customize->add_control(
    'business_way_h5_font_size',
    array(
        'type'    => 'number',
        'label'    => esc_html__('Heading H5 Font Size ', 'business-way'),
        'description'    => esc_html__('Enter Font Size', 'business-way'),
        'section'  => 'business_way_h5_typography_option',
        'input_attrs' => array(
                        'min' => '20',
                        'max' => '50',
                        'step' => '1',
                ),
        'priority' => 30
    )
);

/**
 * Site h5 Font Weight
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
    'business_way_h5_font_weight',
    array(
        'default'           => $default['business_way_h5_font_weight'],
        'sanitize_callback' => 'business_way_sanitize_number',
    )
);
$wp_customize->add_control(
    'business_way_h5_font_weight',
    array(
        'type'     => 'number',
        'label'    => esc_html__('Heading H5 Font Weight ', 'business-way'),
        'description'    => esc_html__('Enter Font Weight Value', 'business-way'),
        'section'  => 'business_way_h5_typography_option',
        'priority' => 30
    )
);

/**
 * Site h5 Letter Spacing
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
    'business_way_h5_letter_spacing',
    array(
        'default'           => $default['business_way_h5_letter_spacing'],
        'sanitize_callback' => 'business_way_sanitize_number',
    )
);
$wp_customize->add_control(
    'business_way_h5_letter_spacing',
    array(
        'type'    => 'number',
        'label'    => esc_html__('Heading H5 Letter Spacing', 'business-way'),
        'description'    => esc_html__('Enter Letter Spacing', 'business-way'),
        'section'  => 'business_way_h5_typography_option',
        'input_attrs' => array(
                        'min' => '-20',
                        'max' => '4',
                        'step' => '1',
                ),
        'priority' => 30
    )
);

/**
 * Heading h6 Font Family Section
 *
 * @since 1.0.0
 */
$wp_customize->add_section(
    'business_way_h6_typography_option',
    array(
        'title'    => esc_html__('Heading H6 Options', 'business-way'),
        'panel'    => 'business_way_typography_options',
        'priority' => 3,
    )
);

/**
 * Site h6 Font Family URL
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
    'business_way_h6_font_family_url',
    array(
        'default'           => $default['business_way_h6_font_family_url'],
        'sanitize_callback' => 'esc_url_raw',
    )
);
$wp_customize->add_control(
    'business_way_h6_font_family_url',
    array(
        'type'     => 'url',
        'label'    => esc_html__('Heading H6 Family URL ', 'business-way'),
        'description' => sprintf('%1$s <a href="%2$s" target="_blank">%3$s</a> %4$s',
        __( 'Insert', 'business-way' ),
        esc_url('https://www.google.com/fonts'),
        __('Google Font URL' , 'business-way'),
        __('for embed fonts.' ,'business-way')
        ),
        'section'  => 'business_way_h6_typography_option',
        'priority' => 30
    )
);
/**
 * Site h6 Family Name
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
    'business_way_h6_font_family_name',
    array(
        'default'           => $default['business_way_h6_font_family_name'],
        'sanitize_callback' => 'sanitize_text_field',
    )
);
$wp_customize->add_control(
    'business_way_h6_font_family_name',
    array(
        'type'     => 'text',
        'label'    => esc_html__('Heading H6 Family Name ', 'business-way'),
        'description'    => esc_html__('Add Font Family Name For Site H6', 'business-way'),
        'section'  => 'business_way_h6_typography_option',
        'priority' => 30
    )
);

/**
 * Site h6 font size
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
    'business_way_h6_font_size',
    array(
        'default'           => $default['business_way_h6_font_size'],
        'sanitize_callback' => 'business_way_sanitize_number',
    )
);
$wp_customize->add_control(
    'business_way_h6_font_size',
    array(
        'type'    => 'number',
        'label'    => esc_html__('Heading H6 Font Size ', 'business-way'),
        'description'    => esc_html__('Enter Font Size', 'business-way'),
        'section'  => 'business_way_h6_typography_option',
        'input_attrs' => array(
                        'min' => '20',
                        'max' => '50',
                        'step' => '1',
                ),
        'priority' => 30
    )
);

/**
 * Site h6 Font Weight
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
    'business_way_h6_font_weight',
    array(
        'default'           => $default['business_way_h6_font_weight'],
        'sanitize_callback' => 'business_way_sanitize_number',
    )
);
$wp_customize->add_control(
    'business_way_h6_font_weight',
    array(
        'type'     => 'number',
        'label'    => esc_html__('Heading H6 Font Weight ', 'business-way'),
        'description'    => esc_html__('Enter Font Weight Value', 'business-way'),
        'section'  => 'business_way_h6_typography_option',
        'priority' => 30
    )
);

/**
 * Site h6 Letter Spacing
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
    'business_way_h6_letter_spacing',
    array(
        'default'           => $default['business_way_h6_letter_spacing'],
        'sanitize_callback' => 'business_way_sanitize_number',
    )
);
$wp_customize->add_control(
    'business_way_h6_letter_spacing',
    array(
        'type'    => 'number',
        'label'    => esc_html__('Heading H6 Letter Spacing', 'business-way'),
        'description'    => esc_html__('Enter Letter Spacing', 'business-way'),
        'section'  => 'business_way_h6_typography_option',
        'input_attrs' => array(
                        'min' => '-20',
                        'max' => '4',
                        'step' => '1',
                ),
        'priority' => 30
    )
);

/**
 * Menu Font Family Section
 *
 * @since 1.0.0
 */
$wp_customize->add_section(
    'business_way_menu_typography_option',
    array(
        'title'    => esc_html__('Menu Font Options', 'business-way'),
        'panel'    => 'business_way_typography_options',
        'priority' => 3,
    )
);

/**
 * Menu Font Family 
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
    'business_way_menu_font_family_url',
    array(
        'default'           => $default['business_way_menu_font_family_url'],
        'sanitize_callback' => 'esc_url_raw',
    )
);
$wp_customize->add_control(
    'business_way_menu_font_family_url',
    array(
        'type'     => 'url',
        'label'    => esc_html__('Menu Font Family URL ', 'business-way'),
        'description' => sprintf('%1$s <a href="%2$s" target="_blank">%3$s</a> %4$s',
        __( 'Insert', 'business-way' ),
        esc_url('https://www.google.com/fonts'),
        __('Google Font URL' , 'business-way'),
        __('for embed fonts.' ,'business-way')
        ),
        'section'  => 'business_way_menu_typography_option',
        'priority' => 30
    )
);

/**
 * Menu Font Family Name
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
    'business_way_menu_font_family_name',
    array(
        'default'           => $default['business_way_menu_font_family_name'],
        'sanitize_callback' => 'sanitize_text_field',
    )
);
$wp_customize->add_control(
    'business_way_menu_font_family_name',
    array(
        'type'     => 'text',
        'label'    => esc_html__('Menu Font Family Name ', 'business-way'),
        'description'    => esc_html__('Add Font Family Name For Menus, Example: Source Sans Pro, sans-serif', 'business-way'),
        'section'  => 'business_way_menu_typography_option',
        'priority' => 30
    )
);

/**
 * Menu font size
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
    'business_way_menu_font_size',
    array(
        'default'           => $default['business_way_menu_font_size'],
        'sanitize_callback' => 'business_way_sanitize_number',
    )
);
$wp_customize->add_control(
    'business_way_menu_font_size',
    array(
        'type'    => 'number',
        'label'    => esc_html__('Menu Font Size ', 'business-way'),
        'description'    => esc_html__('Enter Font Size', 'business-way'),
        'section'  => 'business_way_menu_typography_option',
        'input_attrs' => array(
                        'min' => '6',
                        'max' => '30',
                        'step' => '1',
                ),
        'priority' => 30
    )
);

/**
 * Menu Font Weight
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
    'business_way_menu_font_weight',
    array(
        'default'           => $default['business_way_menu_font_weight'],
        'sanitize_callback' => 'business_way_sanitize_number',
    )
);
$wp_customize->add_control(
    'business_way_menu_font_weight',
    array(
        'type'     => 'number',
        'label'    => esc_html__('Menu Font Weight ', 'business-way'),
        'description'    => esc_html__('Enter Font Weight Value', 'business-way'),
        'section'  => 'business_way_menu_typography_option',
        'priority' => 30
    )
);

/**
 * Menu Line Height
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
    'business_way_menu_line_height',
    array(
        'default'           => $default['business_way_menu_line_height'],
        'sanitize_callback' => 'business_way_sanitize_floatnumber',
    )
);
$wp_customize->add_control(
    'business_way_menu_line_height',
    array(
        'type'    => 'number',
        'label'    => esc_html__('Menu Line Height ', 'business-way'),
        'description'    => esc_html__('Enter Line Height', 'business-way'),
        'section'  => 'business_way_menu_typography_option',
        'input_attrs' => array(
                        'min' => '0',
                        'max' => '4',
                        'step' => '0.1',
                ),
        'priority' => 30
    )
);

/**
 * Letter Spacing
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
    'business_way_menu_letter_spacing',
    array(
        'default'           => $default['business_way_menu_letter_spacing'],
        'sanitize_callback' => 'business_way_sanitize_number',
    )
);
$wp_customize->add_control(
    'business_way_menu_letter_spacing',
    array(
        'type'    => 'number',
        'label'    => esc_html__('Menu Letter Spacing', 'business-way'),
        'description'    => esc_html__('Enter Letter Spacing', 'business-way'),
        'section'  => 'business_way_menu_typography_option',
        'input_attrs' => array(
                        'min' => '-20',
                        'max' => '4',
                        'step' => '1',
                ),
        'priority' => 30
    )
);