<?php
/**
 * Class for adding Our Features Section Widget
 *
 * @package Canyon Themes
 * @subpackage Canyon
 * @since 1.0.0
 */
if( !class_exists( 'Business_Way_Client_Widget') ){

    class Business_Way_Client_Widget extends WP_Widget
    {
        private function defaults()
        {
            /*defaults values for fields*/
            $defaults = array(
                 'clinets_title'     => esc_html__('TOP SPONSORS', 'business-way'),
                 'clinets_sub_title' => esc_html__('Consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.', 'business-way'),
                 'client_image'      => '',
                 'client_image_link' => '',
            );
            return $defaults;
        }

        public function __construct()
        {
            parent::__construct(
                /*Base ID of your widget*/
                'business-way-clients',
                /*Widget name will appear in UI*/
                 esc_html__('CT: Clients Widget', 'business-way'),
                 /*Widget description*/
                 array('description' => esc_html__('CT: Clients Widget', 'business-way'))
            );
        }
        /**
         * Function to Creating widget front-end. This is where the action happens
         *
         * @access public
         * @since 1.0
         *
         * @param array $args widget setting
         * @param array $instance saved values
         *
         * @return void
         *
         */

        public function widget( $args, $instance )
        {
            if ( !empty( $instance ) )
             {
                $instance           = wp_parse_args( (array) $instance, $this->defaults() );
                /*default values*/
                $clinets_title      = apply_filters( 'widget_title', !empty( $instance['clinets_title'] ) ? esc_html( $instance['clinets_title'] ) : '', $instance, $this->id_base);
                $clinets_sub_title  = esc_html($instance['clinets_sub_title']);
                $features = ( ! empty( $instance['features'] ) ) ? $instance['features'] : array();
                echo $args['before_widget'];
                if (isset($features) ) :
                ?>
                <!-- Start Sponsors Section -->
                <section class="bg-sponsors-section">
                    <div class="container">
                        <div class="row">
                            <div class="sponsors-option">
                                <?php if(!empty( $clinets_title ) || !empty($clinets_sub_title) ) { ?>
                                    <div class="section-header text-center">
                                        <h2><?php echo $clinets_title; ?></h2>
                                        <span class="double-border"></span>
                                        <p><?php echo $clinets_sub_title; ?></p>
                                    </div><!-- .section-header -->
                          <?php } ?>
                                <div class="sponsors-container">
                                    <div class="swiper-wrapper">
                                        <?php
                                         foreach( $features as $feature ) {
                                        ?>
                                               <div class="swiper-slide">
                                                <div class="sopnsors-items">
                                                    <a href="<?php echo esc_url( $feature['client_image_link'] ); ?>"><img src="<?php echo esc_url($feature['client_image']); ?>" alt="sponsors-img-1" class="img-responsive" /></a>
                                                </div>
                                            </div><!-- .swiper-slide -->
                                  <?php } ?>
                                    </div>
                                </div>
                            </div>
                        </div><!-- .row -->
                    </div><!-- .container -->
                </section>
                <!-- End Sponsors Section -->
                <?php
                endif;
                echo $args['after_widget'];
            }
        }

        /**
         * Function to Updating widget replacing old instances with new
         *
         * @access public
         * @since 1.0
         *
         * @param array $new_instance new arrays value
         * @param array $old_instance old arrays value
         *
         * @return array
         *
         */
        public function update( $new_instance, $old_instance )
         {
            $instance                      = $old_instance;
            $instance['clinets_title']     = (isset($new_instance['clinets_title'])) ? sanitize_text_field( $new_instance['clinets_title'] ) : '';
            $instance['clinets_sub_title'] = (isset($new_instance['clinets_sub_title'])) ? sanitize_text_field( $new_instance['clinets_sub_title'] ) : '';
            foreach($new_instance['features'] as $feature)
            {
                $feature['client_image']       = esc_url_raw( $feature['client_image'] );
                //$feature['client_image_link']  = esc_url_raw( $feature['client_image_link'] );

            }
            $instance['features']          = $new_instance['features'];

            return $instance;

        }
        /*Widget Backend*/
        public function form( $instance )
        {
            $instance                = wp_parse_args( (array) $instance, $this->defaults() );
            /*default values*/
            $business_way_clinets_title     = esc_attr( $instance[ 'clinets_title' ] );
            $business_way_clinets_sub_title = esc_attr( $instance[ 'clinets_sub_title' ] );
            $features = ( ! empty( $instance['features'] ) ) ? $instance['features'] : array();
            ?>
            <p>
                <label for="<?php echo esc_attr( $this->get_field_id('clinets_title')); ?>">
                    <strong><?php esc_html_e('Title', 'business-way'); ?></strong></label><br/>
                <input type="text" name="<?php echo esc_attr( $this->get_field_name( 'clinets_title') ); ?>" class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'clinets_title' ) ); ?>" value="<?php echo $business_way_clinets_title?>">
            </p>
            <p>

                <label for="<?php echo esc_attr( $this->get_field_id('clinets_sub_title')); ?>">
                    <strong><?php esc_html_e('Sub Title', 'business-way'); ?></strong></label><br/>
                <input type="text" name="<?php echo esc_attr( $this->get_field_name( 'clinets_sub_title') ); ?>" class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'clinets_sub_title' ) ); ?>" value="<?php echo $business_way_clinets_sub_title?>">
            </p>

           <span class="business-way-clients-additional">
            <?php
                $c = 0;
                if ( count( $features ) > 0 )
                {
                    foreach( $features as $feature )
                    {
                     if ( isset( $feature['client_image'] ) || isset( $feature['client_image_link'] ) )
                        {
                            ?>
                            <div class="business-way-clients-section">
                                <p>
                                    <label for="<?php echo $this->get_field_name( 'features' ) . '['.$c.'][client_image]'; ?>">
                                       <strong> <?php esc_html_e( 'Client Image', 'business-way' ); ?></strong>
                                    </label>
                                    <br/>
                                    <?php
                                    if (!empty( $feature['client_image'] )) :
                                        echo '<img class="custom_media_image widefat" src="' . esc_url($feature['client_image']) . '"/><br />';
                                    endif;
                                    ?>
                                    <input type="text" class="widefat custom_media_url" name="<?php echo $this->get_field_name( 'features' ) . '['.$c.'][client_image]'; ?>" id="<?php echo $this->get_field_id( 'features' ) .'-'. $c.'-client_image'; ?>" value="<?php echo esc_url( $feature['client_image'] ); ?>"/>
                                    <input type="button" data-id="<?php echo esc_url( $feature['client_image'] ); ?>" class="button media-image-upload button-primary custom_media_button" id="custom_media_button" name="<?php echo $this->get_field_name( 'features' ) . '['.$c.'][client_image]'; ?>" value="<?php esc_attr_e('Upload Image', 'business-way') ?>"/>
                                </p>
                                <p>
                                    <label for="<?php echo $this->get_field_name( 'features' ) . '['.$c.'][client_image_link]'; ?>">
                                        <strong><?php esc_html_e('Enter URL', 'business-way'); ?></strong>
                                    </label><br/>
    <input type="text" name="<?php echo $this->get_field_name( 'features' ).'['.$c.'][client_image_link]'; ?>" class="widefat" id="<?php echo $this->get_field_id( 'features' ) .'-'. $c.'-client_image_link'; ?>" value="<?php echo esc_url($feature['client_image_link'] ); ?>">
                                </p>
                             <a class="business-way-clients-remove delete"><strong><?php _e('Remove Clients Section','business-way'); ?></strong></a>
                            </div>
                         <?php
                        }
                         $c++;
                    }
                } ?>
            </span>
             <a class="business-way-clients-add button"><strong><?php _e('Add New Clients Section','business-way'); ?></strong></a>
            <?php
        }
    }
}

add_action( 'widgets_init', 'business_way_client_widget' );
function business_way_client_widget()
{
    register_widget( 'Business_Way_Client_Widget' );
}










