<?php
/**
* Class for adding Our Testimonials Section Widget
*
* @package Canyon Themes
* @subpackage Business Way
* @since 1.0.0
*/
if ( !class_exists( 'Business_Way_Testimonial_Widget' ) )
{
    class Business_Way_Testimonial_Widget extends WP_Widget

    {

        private function defaults()
        /* Default Value */
        {
            $defaults = array(
             'title'               => esc_html__('What Customer Say','business-way'),
            'sub_title'           => esc_html__('Check Our All Testimonials','business-way'),
            'bg_image' => '',
            'features'   =>'',
            );
            return $defaults;
        }

    public function __construct()

        {
            parent::__construct(
            /*Widget ID */
            'business_way_testimonial_widget',
            /*Widget Name */
            esc_html__( 'Business Way Testimonial Widget', 'business-way' ),
            /*Widget Description */
            array('description' => esc_html__( 'Business Way Testimonial Section', 'business-way' ) )
            );
        }
        /**
         * Function to Creating widget front-end. This is where the action happens
         *
         * @access public
         * @since 1.0
         *
         * @param array $args widget setting
         * @param array $instance saved values
         *
         * @return void
         *
         */
        public function widget($args, $instance)
        {
            if (!empty($instance))
            {
                $instance  = wp_parse_args((array )$instance, $this->defaults());

                $title        = apply_filters('widget_title', !empty($instance['title']) ? esc_html( $instance['title']): '', $instance, $this->id_base);
                $subtitle     =  esc_html( $instance['sub_title'] );

                $bg_image  = esc_url($instance['bg_image']);

                $features  = ( ! empty( $instance['features'] ) ) ? $instance['features'] : array();

                echo $args['before_widget'];

                ?>
               <!-- Testimonial Start -->

        <div class="testimonial" style="background: #f1f1f1 url(<?php echo esc_url($bg_image); ?>)">
            <?php if (isset($features) && !empty($features['main'])) : ?>
            <div class="container">
                <div class="sec-title text-center">
                    <?php if ( !empty ( $title ) ) { ?>
                        <h3><?php echo $args['before_title'] . $title . $args['after_title']; ?></h3>
                    <?php } ?>
                    <span class="double-border"></span>
                    <?php if ( !empty( $subtitle ) ) { ?>
                    <p><?php echo $subtitle; ?></p>
                    <?php } ?>
                </div>
                <div class="testimonial-slider text-center">
                    <div id="test-slide" class="owl-carousel owl-theme">
                      <?php
                        $post_in = array();
                        if  (count($features) > 0 && is_array($features) )
                        {
                          $post_in[0] = $features['main'];
                          foreach ( $features as $our_testimonials )
                          {
                            if( isset( $our_testimonials['page_ids'] ) && !empty( $our_testimonials['page_ids'] ) )
                            {
                             $post_in[] = $our_testimonials['page_ids'];
                           }
                         }
                       }
                       if( !empty( $post_in )) :
                        $testimonials_page_args = array(
                          'post__in'         => $post_in,
                          'orderby'             => 'post__in',
                          'posts_per_page'      => count( $post_in ),
                          'post_type'           => 'page',
                          'no_found_rows'       => true,
                          'post_status'         => 'publish'
                        );
                        $testimonials_query = new WP_Query( $testimonials_page_args );

                        /*The Loop*/
                        if ( $testimonials_query->have_posts() ):
                          $i = 1;
                          while ( $testimonials_query->have_posts() ):$testimonials_query->the_post();
                            ?>
                      <div class="item">
                        <div class="item-box">
                            <div class="item-img">
                                <?php
                                if (has_post_thumbnail()) {
                                $image_id = get_post_thumbnail_id();
                                $image_url = wp_get_attachment_image_src($image_id, 'full', true);
                                ?>
                                <img src="<?php echo esc_url($image_url[0]); ?>" class="img-responsive">
                                <?php }
                                ?>
                            </div>
                        </div>
                        <div class="item-text">
                            <h4><?php the_title();?></h4>
                            <?php the_excerpt(); ?>
                        </div>
                      </div>
                  <?php endwhile; endif; wp_reset_postdata(); endif; ?>
                    </div><!-- /.owl-carousel -->
                </div><!-- /.custom-slider -->
            </div><!-- /.container -->
        <?php endif; ?>
        </div>
        <!-- Testimonial End -->
                <?php
                echo $args['after_widget'];
            }
        }
        /**
         * Function to Updating widget replacing old instances with new
         *
         * @access public
         * @since 1.0
         *
         * @param array $new_instance new arrays value
         * @param array $old_instance old arrays value
         *
         * @return array
         *
         */

    public function update( $new_instance, $old_instance )
    {
    $instance             = $old_instance;

    $instance['title']     = ( isset( $new_instance['title'])) ? sanitize_text_field($new_instance['title']) : '';
          $instance['sub_title'] = ( isset( $new_instance['sub_title'])) ? sanitize_text_field($new_instance['sub_title']) : '';
    $instance['bg_image'] = esc_url_raw($new_instance['bg_image']);

    if (isset($new_instance['features']))

    {
        foreach($new_instance['features'] as $feature)
        {

         $feature['page_ids'] = absint($feature['page_ids']);
        }

         $instance['features'] = $new_instance['features'];
    }

    return $instance;

    }

    public function form( $instance )
    {
        $instance  = wp_parse_args( (array )$instance, $this->defaults() );
        $title      = esc_attr( $instance['title'] );
        $subtitle   = esc_attr( $instance['sub_title'] );
        $bgimage   = esc_url( $instance['bg_image'] );
        $features     = ( ! empty( $instance['features'] ) ) ? $instance['features'] : array();

        ?>
        <span class="pt-business-way-additional">
            <p>
              <label for="<?php echo esc_attr($this->get_field_id('title')); ?>">
                <?php esc_html_e('Title', 'business-way'); ?>
              </label><br/>
              <input type="text" name="<?php echo esc_attr( $this->get_field_name('title') ); ?>" class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title') ); ?>" value="<?php echo $title; ?>">
            </p>
            <p>
              <label for="<?php echo esc_attr( $this->get_field_id('sub_title') ); ?>">
                <?php esc_html_e( 'Sub Title', 'business-way'); ?>
              </label><br/>
              <input type="text" name="<?php echo esc_attr($this->get_field_name('sub_title')); ?>" class="widefat" id="<?php echo esc_attr($this->get_field_id('sub_title')); ?>" value="<?php echo $subtitle; ?>">
            </p>
            <label><?php _e( 'Select Pages', 'business-way' ); ?>:</label>
            <br/>
            <small><?php _e( 'Select Page and Remove. Please do not forget to add Icon, Featured Image and Excerpt on selected pages.', 'business-way' ); ?></small>
            <?php

            if  ( count( $features ) >=  1 && is_array( $features ) )
            {

              $selected = $features['main'];

            }

            else
            {
                 $selected = "";
            }

            $repeater_id   = $this->get_field_id( 'features' ).'-main';
            $repeater_name = $this->get_field_name( 'features'). '[main]';

            $args = array(
            'selected'          => $selected,
            'name'              => $repeater_name,
            'id'                => $repeater_id,
            'class'             => 'widefat pt-select',
            'show_option_none'  => __( 'Select Page', 'business-way'),
            'option_none_value' => 0 // string
            );
            wp_dropdown_pages( $args );
            $counter = 0;
            if ( count( $features ) > 0 )
            {
                foreach( $features as $feature )
                {

                    if ( isset( $feature['page_ids'] ) )
                        { ?>
                            <div class="pt-business-way-sec">
                                <?php
                                $repeater_id     = $this->get_field_id( 'features' ) .'-'. $counter.'-page_ids';
                                $repeater_name   = $this->get_field_name( 'features' ) . '['.$counter.'][page_ids]';
                                $args = array(
                                'selected'          => $feature['page_ids'],
                                'name'              => $repeater_name,
                                'id'                => $repeater_id,
                                'class'             => 'widefat pt-select',
                                'show_option_none'  => __( 'Select Page', 'business-way'),
                                'option_none_value' => 0 // string
                                );
                                wp_dropdown_pages( $args );
                                ?>
                                <a class="pt-business-way-remove delete"><?php esc_html_e('Remove Section','business-way') ?></a>
                            </div>
                            <?php
                            $counter++;
                        }
                }
            }

            ?>

        </span>
        <a class="pt-business-way-add button" data-id="business_way_testimonial_widget" id="<?php echo $repeater_id; ?>"><?php _e('Add New Section', 'business-way'); ?></a>
        <hr>
        <p>
                <label for="<?php echo $this->get_field_id('bg_image'); ?>">
                    <?php _e( 'Select Background Image', 'business-way' ); ?>:
                </label>
                <span class="img-preview-wrap" <?php  if ( empty( $bgimage ) ){ ?> style="display:none;" <?php  } ?>>
                    <img class="widefat" src="<?php echo esc_url( $bgimage ); ?>" alt="<?php esc_attr_e( 'Image preview', 'business-way' ); ?>"  />
                </span><!-- .img-preview-wrap -->
                <input type="text" class="widefat" name="<?php echo $this->get_field_name('bg_image'); ?>" id="<?php echo $this->get_field_id('bg_image'); ?>" value="<?php echo esc_url( $bgimage ); ?>" />
                <input type="button" id="custom_media_button" value="<?php esc_attr_e( 'Upload Image', 'business-way' ); ?>" class="button media-image-upload" data-title="<?php esc_attr_e( 'Select Background Image','business-way'); ?>" data-button="<?php esc_attr_e( 'Select Background Image','business-way'); ?>"/>
                <input type="button" id="remove_media_button" value="<?php esc_attr_e( 'Remove Image', 'business-way' ); ?>" class="button media-image-remove" />
        </p>

        <?php
        }
        }

}

add_action( 'widgets_init', 'business_way_testimonial_widget' );

function business_way_testimonial_widget()
{
  register_widget( 'Business_Way_Testimonial_Widget' );
}