<?php
if (!class_exists( 'Business_Way_Video_Widget' ) ) {
    class Business_Way_Video_Widget extends WP_Widget
    {
        private function defaults()
        {
            $defaults             = array(
                'title'           => esc_html__('Video Title', 'business-way'),
                'sub_title'       => '',
                'video_link'      => '',
                'bg_image'        => '',

            );

            return $defaults;
        }

        public function __construct()
        {
            parent::__construct(
                'business-way-video-widget',
                esc_html__( 'Business Way Video Widget', 'business-way' ),
                array( 'description' => esc_html__( 'Business Way Video Widget', 'business-way' ) )
            );
        }

        public function widget( $args, $instance )
        {

            if ( !empty( $instance ) ) {
                $instance        = wp_parse_args( (array )$instance, $this->defaults() );
                 $title          = apply_filters('widget_title', !empty($instance['title']) ?esc_html($instance['title']) : '', $instance, $this->id_base);
                $sub_title = esc_html( $instance['sub_title'] );
                $video_link = esc_html( $instance['video_link'] );
                $bg_image  = esc_url($instance['bg_image']);
                echo $args['before_widget']; ?>
                <section  class="video-section" style="background: url(<?php echo $bg_image; ?>) no-repeat fixed; background-size: cover;background-position: 48% 100%;">
                    <div class="video-overlay">
                        <div class="container">
                            <div class="row">
                                <div class="video-section">
                                    <div class="playbtn video">
                                            <a class="video-popup" href="<?php echo esc_url( $video_link ); ?>" data-rel="lightcase:myCollection"><img src="<?php echo get_template_directory_uri()?>/assets/images/video-icon.png" alt="video-icon"></a>
                                             <h3>   <?php echo $title; ?></h3>
                                             <p> <?php echo $sub_title; ?></p>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </section>
                <?php echo $args['after_widget'];
            }
        }

        public function update( $new_instance, $old_instance )
        {
            $instance                    = $old_instance;
            $instance['title'] = sanitize_text_field( $new_instance['title'] );
            $instance['sub_title'] = sanitize_text_field( $new_instance['sub_title'] );
            $instance['video_link'] = sanitize_text_field( $new_instance['video_link'] );
            $instance['bg_image'] = esc_url_raw($new_instance['bg_image']);

            return $instance;
        }

        public function form( $instance )
        {
            $instance        = wp_parse_args((array )$instance, $this->defaults() );
            $title = esc_attr( $instance['title'] );
            $sub_title = esc_attr( $instance['sub_title'] );
            $video_link = esc_attr( $instance['video_link'] );
            $bgimage   = esc_url( $instance['bg_image'] );

            ?>
            <p>
                <label for="<?php echo esc_attr( $this->get_field_id('title')); ?>"><strong><?php esc_html_e('Title', 'business-way'); ?></strong></label><br/>
                <input type="text" name="<?php echo esc_attr( $this->get_field_name('title')); ?>" class="business-way-cons widefat" id="<?php echo esc_attr($this->get_field_id('title')); ?>" value="<?php echo $title ?>">
            </p>
            <hr>
            <p>
                <label for="<?php echo esc_attr( $this->get_field_id('sub_title')); ?>"><strong><?php esc_html_e('Subtitle', 'business-way'); ?></strong></label><br/>
                <textarea class="widefat" rows="5" cols="15" name="<?php echo esc_attr( $this->get_field_name('sub_title')); ?>" class="business-way-cons" id="<?php echo esc_attr($this->get_field_id('sub_title')); ?>" value="<?php echo $sub_title; ?>"><?php echo $sub_title; ?>
                </textarea>
            </p>
            <hr>
            <p>
                <label for="<?php echo esc_attr( $this->get_field_id('video_link')); ?>"><strong><?php esc_html_e('Video Link', 'business-way'); ?></strong></label><br/>
                <input type="text" name="<?php echo esc_attr( $this->get_field_name('video_link')); ?>" class="business-way-cons widefat" id="<?php echo esc_attr($this->get_field_id('video_link')); ?>" value="<?php echo $video_link ?>">
                <em>The Video Link should be like this e.g https://www.youtube.com/embed/T24DPU-hkJM</em>
            </p>
            <hr>
            <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'bg_image' ) ); ?>">
                <strong><?php esc_html_e( 'Background Image', 'business-way' ); ?></strong>
            </label>
            <br/>
            <?php
            if (!empty($bgimage)) :
                echo '<img class="custom_media_image widefat" src="' . $bgimage . '"/><br />';
            endif;
            ?>
            <input type="text" class="widefat custom_media_url" name="<?php echo esc_attr($this->get_field_name('bg_image')); ?>" id="<?php echo esc_attr($this->get_field_id('bg_image')); ?>" value="<?php echo $bgimage; ?>"/>
            <input type="button" class="button button-primary custom_media_button  media-image-upload" id="custom_media_button" name="<?php echo esc_attr($this->get_field_name('bg_image')); ?>" value="<?php esc_attr_e('Upload Image', 'business-way') ?>"/>
            </p>
            <?php
        }
    }

}

add_action( 'widgets_init', 'business_way_video_widget' );

function business_way_video_widget()
{
    register_widget( 'Business_Way_Video_Widget' );

}